---
title: Project Structure and Organization
nav_title: Project Structure
description: Learn about the folder and file conventions in a Next.js project, and how to organize your project.
source: app/getting-started/project-structure
---

{/* DO NOT EDIT. The content of this doc is generated from the source above. To edit the content of this page, navigate to the source page in your editor. You can use the `<PagesOnly>Content</PagesOnly>` component to add content that is specific to the Pages Router. Any shared content should not be wrapped in a component. */}
